summaryrefslogtreecommitdiffstats
path: root/kbabel/kbabel/mymultilineedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kbabel/kbabel/mymultilineedit.h')
-rw-r--r--kbabel/kbabel/mymultilineedit.h18
1 files changed, 10 insertions, 8 deletions
diff --git a/kbabel/kbabel/mymultilineedit.h b/kbabel/kbabel/mymultilineedit.h
index 624e5e4c..10592b0c 100644
--- a/kbabel/kbabel/mymultilineedit.h
+++ b/kbabel/kbabel/mymultilineedit.h
@@ -22,11 +22,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -50,8 +50,9 @@ class TQPixmap;
class MyMultiLineEdit : public KTextEdit
{
Q_OBJECT
+ TQ_OBJECT
public:
- MyMultiLineEdit(int ID,TQWidget* parent,const char* name=0);
+ MyMultiLineEdit(int ID,TQWidget* tqparent,const char* name=0);
/**
applies cmd to the displayed text, but does not emit
@@ -129,7 +130,7 @@ protected:
virtual TQPopupMenu *createPopupMenu();
virtual TQPopupMenu *createPopupMenu(const TQPoint &pos);
/* the parent handles this */
virtual void wheelEvent(TQWheelEvent*);
bool emitUndo;
@@ -173,10 +174,11 @@ private:
class MsgMultiLineEdit : public MyMultiLineEdit
{
Q_OBJECT
+ TQ_OBJECT
public:
enum TextColor { NormalColor, ErrorColor };
- MsgMultiLineEdit(int ID, KSpell* spell=0, TQWidget* parent=0,const char* name=0);
+ MsgMultiLineEdit(int ID, KSpell* spell=0, TQWidget* tqparent=0,const char* name=0);
virtual ~MsgMultiLineEdit();
/** is displaying surrounding quotes enabled? */
@@ -227,7 +229,7 @@ public slots:
/**
* reimplemented to call highlight()
*/
- void repaint();
+ void tqrepaint();
void forceUpdate();
void emittedTextChanged();
@@ -251,7 +253,7 @@ private:
TQRect mapToView( int para, int index );
/**
- * tests if the character in string str at position col is masked with
+ * tests if the character in string str at position col is tqmasked with
* '\' by counting the number of '\' backwards
*/
static bool isMasked(TQString *str,uint col);
@@ -129,7 +130,7 @@ protected:
virtual TQPopupMenu *createPopupMenu();
virtual TQPopupMenu *createPopupMenu(const TQPoint &pos);
- /* the parent handles this */
+ /* the tqparent handles this */
virtual void wheelEvent(TQWheelEvent*);
bool emitUndo;